{#
/**
 * @file
 * Theme override for the basic structure of a single Drupal page.
 *
 * Variables:
 * - logged_in: A flag indicating if user is logged in.
 * - root_path: The root path of the current page (e.g., node, admin, user).
 * - node_type: The content type for the current node, if the page is a node.
 * - head_title: List of text elements that make up the head_title variable.
 *   May contain one or more of the following:
 *   - title: The title of the page.
 *   - name: The name of the site.
 *   - slogan: The slogan of the site.
 * - page_top: Initial rendered markup. This should be printed before 'page'.
 * - page: The rendered page markup.
 * - page_bottom: Closing rendered markup. This variable should be printed after
 *   'page'.
 * - db_offline: A flag indicating if the database is offline.
 * - placeholder_token: The token for generating head, css, js and js-bottom
 *   placeholders.
 *
 * @see template_preprocess_html()
 */
#}
{%
  set body_classes = [
    logged_in ? 'user-logged-in' : 'user-guest',
    not root_path ? 'frontpage' : 'inner-page path-' ~ root_path|clean_class,
    node_type ? 'page-type-' ~ node_type|clean_class,
    not page.sidebar_first and not page.sidebar_second ? 'no-sidebar',
    page.sidebar_first and not page.sidebar_second ? 'one-sidebar sidebar-left',
    page.sidebar_second and not page.sidebar_first ? 'one-sidebar sidebar-right',
    page.sidebar_first and page.sidebar_second ? 'two-sidebar'
  ]
%}
<!DOCTYPE html>
<html{{ html_attributes }}>
  <head>
    <head-placeholder token="{{ placeholder_token|raw }}">
    <title>{{ head_title|safe_join(' | ') }}</title>
    {% if google_font == 'local' %}
    <link rel="preload" as="font" href="{{ base_path ~ directory }}/fonts/open-sans.woff2" type="font/woff2" crossorigin>
    <link rel="preload" as="font" href="{{ base_path ~ directory }}/fonts/roboto.woff2" type="font/woff2" crossorigin>
    {% endif %}
    <css-placeholder token="{{ placeholder_token|raw }}">
    <js-placeholder token="{{ placeholder_token|raw }}">
{% if insert_head %}
  {% include '@tarapro/template-parts/insert-codes/head-codes.html.twig' %}
{% endif %}
{% if color_scheme == 'color_custom' %}
  {% include '@tarapro/template-parts/insert-codes/color.html.twig' %}
{% endif %}
{% if css_extra %}
<style>
{{ css_code | raw }}
</style>
{% endif %}
  </head>
  <body{{ attributes.addClass(body_classes) }}>
{% if insert_body_start %}
  {% include '@tarapro/template-parts/insert-codes/body-start-codes.html.twig' %}
{% endif %}
{% if preloader_option %}
  <div class="loader"></div>
{% endif %}
    {#
      Keyboard navigation/accessibility link to main content section in
      page.html.twig.
    #}
    <a href="#main-content" class="visually-hidden focusable">
      {{ 'Skip to main content'|t }}
    </a>
    {{ page_top }}
    {{ page }}
    {{ page_bottom }}
{% if google_font == 'googlecdn' %}
  {{ attach_library('tarapro/googlefontscdn') }}
{% elseif google_font == 'local' %}
  {{ attach_library('tarapro/googlefontslocal') }}
{% endif %}
    <js-bottom-placeholder token="{{ placeholder_token|raw }}">
{% if sticky_footer %}
<script>
jQuery(window).on("load", function () {
  if (jQuery(window).width() > 767) {
    var footerheight = jQuery("#footer").outerHeight(true);
    jQuery("#last-section").css("height", footerheight);
  }
});
</script>
<style>
@media screen and (min-width: 768px) {
#footer {
  position: fixed;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 0;
}
}
</style>
{% endif %}
{% if preloader_option %}
<script type="text/javascript">
  jQuery(document).ready(function() {
    jQuery(".loader").fadeOut( 'slow' );
  });
</script>
{% endif %}
{% if is_front and slider_show %}
  <script>
  jQuery(document).ready(function ($) {
    $(".home-slider").owlCarousel({
      items: 1,
      loop: true,
      autoplay: true,
      autoplayTimeout: {{ slider_time }},
      nav: false,
      dots: {{ slider_dots }},
			animateOut: '{{ slider_animateout }}',
      animateIn: '{{ slider_animatein }}',
    });
  });
  </script>
{% endif %}
{{ attach_library('tarapro/hjs') }}
{% if insert_body_end %}
  {% include '@tarapro/template-parts/insert-codes/body-end-codes.html.twig' %}
{% endif %}
  </body>
</html>
